This data set (n=841, p = 69) consists of counts of common words appearing in texts written by four popular English-language authors (Jane Austen, Jack London, William Shakespeare, and John Milton). The row names are the authors (true cluster labels) and the column names are the words (slightly processed).
1 |
An object of class matrix (inherits from array) with 841 rows and 69 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.